@@ -11,6 +11,8 @@
 #include <iostream>
 #include <list>
 
+using namespace std;
+
 extern int debug;
 extern bool testmode;
 
@@ -47,10 +49,25 @@ public:
 		}
 		return *this;
 	}
+	PACKAGE (const PACKAGE &pkg)
+	{
+		name = pkg.name;
+		version = pkg.version;
+	}
 	bool operator == (const PACKAGE &v) const
 	{
 		return name == v.name && version == v.version;
 	}
+	bool operator < (const PACKAGE &v) const
+	{
+		bool ret = false;
+		if (name < v.name){
+			ret = true;
+		}else if (name == v.name && version < v.version){
+			ret = true;
+		}
+		return ret;
+	}
 	// Load the file member of the package, but exclude configuration file
 	void loadfiles(const string &ref, set<string> &files)
 	{
@@ -97,6 +114,16 @@ public:
 	#endif
 };
 
+// Check if two package have the same name (but potentially different version)
+class same_name{
+	const PACKAGE &pkg;
+public:
+	same_name(const PACKAGE &_pkg) : pkg(_pkg) {}
+	bool operator()(const PACKAGE &p)
+	{
+		return pkg.name == p.name;
+	}
+};
 
 #include "vutil.p"
 
